@@ -4,6 +4,9 @@
 
 from zope.interface import implements, directlyProvides
 
+from Products.Archetypes.public import * 
+from Products.ATExtensions.ateapi import *
+
 from Products.Archetypes import atapi
 from Products.ATContentTypes.content import base
 from Products.ATContentTypes.content import schemata
@@ -22,6 +25,7 @@ from acted.projects.config import ACTED_SECTORS
 from acted.projects.config import ACTED_DONORS
 from acted.projects.config import ACTED_YEARS
 
+import re
 
 
 ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
@@ -85,6 +89,7 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
         format='select',
         size=25
       ),
+      accessor='getProjectDonor',
       vocabulary=ACTED_DONORS,
       enforceVocabulary=True,
       required=False,
@@ -154,5 +159,12 @@ class ACTEDProject(base.ATCTContent):
     
     # -*- Your ATSchema to Python Property Bridges Here ... -*-
 
+    def getProjectDonor(self):
+        theDonors = self.getField('projectDonor').get(self)
+        retval = ''
+        for theDonor in theDonors:
+            theDonor = re.sub('^-* ', '', theDonor)
+            retval = retval + theDonor + ', '
+        return retval[:-4]
 
 atapi.registerType(ACTEDProject, PROJECTNAME)
